@@ -18,9 +18,7 @@
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string.hpp>
 #include <boost/algorithm/string/replace.hpp>
-#include <boost/filesystem.hpp>
-
-using namespace boost;
+#include <filesystem>
 
 #define LOCAL_SECTION LOG_CONVERT
 #define LOCAL_LEVEL	LOG_DEF_LEVEL
@@ -266,7 +264,7 @@ int MedConvert::prep_sids_to_load()
 void get_rel_filename(vector<string> &paths) {
 	for (size_t i = 0; i < paths.size(); i++)
 	{
-		boost::filesystem::path pt(paths[i]);
+		std::filesystem::path pt(paths[i]);
 		paths[i] = pt.filename().string();
 	}
 }
@@ -386,8 +384,8 @@ int MedConvert::read_all(const string &config_fname)
 	for (string d : dict_fnames)
 	{
 		add_path_to_name_IM(out_path, d);
-		boost::filesystem::path pt_dict(d);
-		boost::filesystem::create_directories(pt_dict.parent_path().string());
+		std::filesystem::path pt_dict(d);
+		std::filesystem::create_directories(pt_dict.parent_path().string());
 	}
 	if (copy_files_IM(path, out_path, dict_fnames) < 0)
 		MTHROW_AND_ERR("MedConvert : read_all() : failed copying files from in to out directory\n");
@@ -1355,9 +1353,9 @@ int MedConvert::generate_prefix_names()
 	serial2siginfo.clear();
 	for (int i = 0; i < sigs.signals_names.size(); i++) {
 		string fixed_sig_name = sigs.signals_names[i];
-		replace_all(fixed_sig_name, "/", "_div_");
-		replace_all(fixed_sig_name, ":", "_over_");
-		replace_all(fixed_sig_name, "%", "_percent_");
+		boost::replace_all(fixed_sig_name, "/", "_div_");
+		boost::replace_all(fixed_sig_name, ":", "_over_");
+		boost::replace_all(fixed_sig_name, "%", "_percent_");
 		string name = rep_files_prefix + "_" + fixed_sig_name; //sigs.signals_names[i];
 		int sid = sigs.sid(sigs.signals_names[i]); // signals_ids[i];
 		prefix_names.push_back(name);
