@@ -184,8 +184,8 @@ public:
 	void init_from_json_file_with_alterations(const string& fname, vector<string>& alterations);
 	int add_pre_processors_json_string_to_model(string in_json, string fname) { vector<string> dummy; return add_pre_processors_json_string_to_model(in_json, fname, dummy); }
 	int add_pre_processors_json_string_to_model(string in_json, string fname, vector<string> &alterations, bool add_rep_first = false);
-	int add_post_processors_json_string_to_model(string in_json, string fname) { vector<string> dummy; return add_post_processors_json_string_to_model(in_json, fname, dummy); }
-	int add_post_processors_json_string_to_model(string in_json, string fname, vector<string> &alterations);
+	int add_post_processors_json_string_to_model(const string &in_json, const string &fname) { vector<string> dummy; return add_post_processors_json_string_to_model(in_json, fname, dummy); }
+	int add_post_processors_json_string_to_model(const string &in_json, const string &fname, const vector<string> &alterations);
 	void add_rep_processor_to_set(int i_set, const string &init_string);		// rp_type and signal are must have parameters in this case
 	void add_feature_generator_to_set(int i_set, const string &init_string);	// fg_type and signal are must have parameters
 	void add_feature_processor_to_set(int i_set, int duplicate, const string &init_string);	// fp_type and feature name are must have parameters
@@ -305,9 +305,9 @@ private:
 	string parse_key_val(string key, string val);
 	void fill_list_from_file(const string& fname, vector<string>& list);
 	string make_absolute_path(const string& main_file, const string& small_file, bool use_cwd = false);
-	void alter_json(string &json_contents, vector<string>& alterations);
+	void alter_json(string &json_contents, const vector<string>& alterations);
 	void insert_environment_params_to_json(string& json_content);
-	string json_file_to_string(int recursion_level, const string& main_file, vector<string>& alterations, const string& small_file = "", bool add_change_path = false);
+	string json_file_to_string(int recursion_level, const string& main_file, const vector<string>& alterations, const string& small_file = "", bool add_change_path = false);
 	void parse_action(basic_ptree<string, string>& action, vector<vector<string>>& all_action_attrs, int& duplicate, ptree& root, const string& fname);
 	int apply_predictor(MedSamples &samples);
 
